/***************************************************************************//**
*   @file   main.c
*   @brief  Main File for AD7193 Driver.
*   @author ATofan (alexandru.tofan@analog.com)
********************************************************************************
* Copyright 2012(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR
* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
* LIMITED TO, INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR
* SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
* CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
********************************************************************************
*   SVN Revision: $WCREV$
*******************************************************************************/

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/
#include <stdio.h>
#include "xparameters.h"
#include "xil_cache.h"
#include "xil_io.h"
#include "spi.h"
#include "AD7193.h"

/******************************************************************************
* @brief Main function.
*
* @return Always returns 0.
******************************************************************************/
int main() 
{

	Xil_ICacheEnable();
	Xil_DCacheEnable();

	SPI_Init(SPI_BASEADDR, 0, 1, 1);

	xil_printf("\n\rPmodAD5 Demonstration Program\n\r\n\r");
	xil_printf(">>> Initial Register Values for AD7193 <<<\n\r");
	xil_printf("Status Register: 0x%x\n\r", ReadStatusReg());
	xil_printf("Mode Register: 0x%x\n\r",ReadModeReg());
	xil_printf("Config Register: 0x%x\n\r",ReadConfigReg());
	xil_printf("ID Register: 0x%x\n\r",ReadIDReg());
	xil_printf("GPOCON Register: 0x%x\n\r",ReadGPOCONReg());
	xil_printf("Offset Register: 0x%x\n\r",ReadOffsetReg());
	xil_printf("Full scale Register: 0x%x\n\r",ReadFullScaleReg());
	xil_printf("Press any key to continue...\n\r");
	xil_printf("\n\r");

	// Read pressed key
	while(!((Xil_In32(XPAR_USB_UART_BASEADDR + 0x08)) & 0x01));
	Xil_In32(XPAR_USB_UART_BASEADDR);

	while(1)
	{
		AD7193_DemoMode1();
		AD7193_DemoMode2();
		AD7193_DemoMode3();
		AD7193_DemoMode4();
		AD7193_DemoMode5();
	}

	Xil_DCacheDisable();
	Xil_ICacheDisable();

	return 0;
}

